# Generated by roxygen2: do not edit by hand

S3method(apa_table,content_validity)
S3method(plot,content_validity)
S3method(print,content_validity)
export(aiken_v)
export(apa_table)
export(content_validity)
export(cv_sample_size_icvi)
export(cvr)
export(cvr_critical)
export(gwet_ac1)
export(gwet_ac2)
export(icvi)
export(mod_kappa)
export(scvi_ave)
export(scvi_ua)
importFrom(grDevices,dev.off)
importFrom(graphics,abline)
importFrom(graphics,legend)
importFrom(graphics,text)
importFrom(stats,pbinom)
importFrom(stats,pnorm)
importFrom(stats,qnorm)
importFrom(stats,quantile)
importFrom(stats,setNames)
importFrom(stats,uniroot)
