% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/contentValidity-package.R
\docType{package}
\name{contentValidity-package}
\alias{contentValidity}
\alias{contentValidity-package}
\title{contentValidity: Content Validity Indices for Instrument Development}
\description{
The \code{contentValidity} package provides functions for computing content
validity indices used in questionnaire and instrument development,
including the Item-level and Scale-level Content Validity Indices,
modified kappa, Aiken's V, and Lawshe's CVR with corrected critical
values.
}
\section{Main functions}{

\itemize{
\item \code{\link[=icvi]{icvi()}}: Item-level Content Validity Index
\item \code{\link[=scvi_ave]{scvi_ave()}}: Scale-level CVI, average method
\item \code{\link[=scvi_ua]{scvi_ua()}}: Scale-level CVI, universal agreement method
\item \code{\link[=mod_kappa]{mod_kappa()}}: Modified kappa adjusted for chance agreement
\item \code{\link[=aiken_v]{aiken_v()}}: Aiken's V coefficient
\item \code{\link[=cvr]{cvr()}}: Lawshe's Content Validity Ratio
\item \code{\link[=cvr_critical]{cvr_critical()}}: Critical CVR values (Wilson, Pan & Schumsky 2012)
}
}

\seealso{
Useful links:
\itemize{
  \item \url{https://github.com/Rafhq1403/contentValidity}
  \item Report bugs at \url{https://github.com/Rafhq1403/contentValidity/issues}
}

}
\author{
\strong{Maintainer}: Rashed Alqahtani \email{rashed.alqahtani@gmail.com}

Authors:
\itemize{
  \item Rashed Alqahtani \email{rashed.alqahtani@gmail.com}
}

}
\keyword{internal}
